==> kubernetes-model-1.0.29-sources.jar: io/fabric8/kubernetes/api/model/QuantityFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;

public class QuantityFluentImpl<T extends QuantityFluent<T>> extends BaseFluent<T> implements QuantityFluent<T>{

     String amount;     String format;     Map<String, Object> additionalProperties = new HashMap();

    public String getAmount(){
    return this.amount;
    }
    public T withAmount( String amount){
    this.amount=amount; return (T) this;
    }
    public String getFormat(){
    return this.format;
    }
    public T withFormat( String format){
    this.format=format; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
QuantityFluentImpl that = (QuantityFluentImpl) o;
if (amount != null ? !amount.equals(that.amount) :that.amount != null) return false;
if (format != null ? !format.equals(that.format) :that.format != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}

==> kubernetes-model-1.0.31-sources.jar: io/fabric8/kubernetes/api/model/QuantityFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;

public class QuantityFluentImpl<T extends QuantityFluent<T>> extends BaseFluent<T> implements QuantityFluent<T>{

     String amount;     String format;     Map<String, Object> additionalProperties = new HashMap();

    public String getAmount(){
    return this.amount;
    }
    public T withAmount( String amount){
    this.amount=amount; return (T) this;
    }
    public String getFormat(){
    return this.format;
    }
    public T withFormat( String format){
    this.format=format; return (T) this;
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
QuantityFluentImpl that = (QuantityFluentImpl) o;
if (amount != null ? !amount.equals(that.amount) :that.amount != null) return false;
if (format != null ? !format.equals(that.format) :that.format != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }



}
